srwExtensions

|  | ## Cheshire3: srwExtensions Module

Module srwExtensions

Functions | [hide private]
simpleRequestXform(item, config)
implementationResponseHandler(req, resp, other=None)
docidRecordHandler(req, ro, other)

Variables | [hide private]
r |

Function Details | [hide private]

### simpleRequestXform(item, config) | source code

### implementationResponseHandler(req, resp, other=None) | source code

### docidRecordHandler(req, ro, other) | source code

Variables Details | [hide private]

    ### r Value:
        <utils.reader instance at 0xb732fd2c>